@@ -13,17 +13,21 @@
 #with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 
-import gtk
-import gobject
+#import Gtk
+#import gobject
+#import GLib
+from gi.repository import Gtk
+from gi.repository import GObject
+from gi.repository import GLib
+
 import os
-import glib
 import gettext
 from gettext import gettext as _
 gettext.textdomain('quickly-widgets')
 
 #TODO: stop using **kwargs and go back to named arguments so you can pass them from the function to the class
 
-class Prompt(gtk.Dialog):
+class Prompt(Gtk.Dialog):
     """A base class for some quickly.prompts - creates Ok and Cancel buttons,
     displays a title and a label.
 
@@ -45,20 +49,20 @@ class Prompt(gtk.Dialog):
 
     Configuring
     #add some widgets to the prompt using the
-    #the prompt's content_box member (which is a gtk.VBox)
+    #the prompt's content_box member (which is a Gtk.VBox)
     #These widgets will appear below the label
     #StringPrompt works similar to this:
     p = quickly.prompts.Prompt(title,text)
-    entry = gtk.Entry()
+    entry = Gtk.Entry()
     entry.set_text(default_value)
     entry.set_activates_default(True)
     entry.show()
     p.content_box.pack_end(entry, True, True, 5)
     response = p.run()
-    if response = gtk.RESPONSE_OK:
+    if response = Gtk.ResponseType.OK:
         my_string = entry.get_text()
 
-    #A Prompt is a gtk.Dialog, so you can use gtk.DialogMembers
+    #A Prompt is a Gtk.Dialog, so you can use Gtk.DialogMembers
     action_area = p.get_action_area()
 
     Extending 
@@ -69,7 +73,7 @@ class Prompt(gtk.Dialog):
         def __init__(self, title = "Input String",
                      text = "Input a String:", default_value = ""):
             Prompt.__init__(self, title, text)
-            self._entry = gtk.Entry()
+            self._entry = Gtk.Entry()
             self._entry.set_text(default_value)
             self._entry.set_activates_default(True)
             self._entry.show()
@@ -88,17 +92,17 @@ class Prompt(gtk.Dialog):
 
         """
 
-        gtk.Dialog.__init__(self, title, None, gtk.DIALOG_MODAL,(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
-        self.set_has_separator(False)
+        Gtk.Dialog.__init__(self, title, None, Gtk.DialogFlags.MODAL,(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OK, Gtk.ResponseType.OK))
+        #self.set_has_separator(False)
         content_area = self.get_content_area()
         content_area.set_border_width(5)
-        self.set_default_response(gtk.RESPONSE_OK)
+        self.set_default_response(Gtk.ResponseType.OK)
 
-        self.content_box = gtk.VBox(False, 10)
-        label = gtk.Label(text)
+        self.content_box = Gtk.VBox(False, 10)
+        label = Gtk.Label(text)
         label.set_line_wrap(True)
         self.content_box.pack_start(label,False, False, 5)
-        content_area.pack_start(self.content_box)
+        content_area.pack_start(self.content_box,False, False, 5)
         self.content_box.show()
         label.show()
 
@@ -110,10 +114,10 @@ def string(title = _("Input String"), text = _("Input a String:"), default_value
     text - a string to provide a prompt for the user within dialog
     default_value - a string to see the entry in the dialog box
 
-    returns a tuple of (gtk.DialogResponse, string value)
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+    returns a tuple of (Gtk.DialogResponse, string value)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
 
     """
 
@@ -130,19 +134,19 @@ class StringPrompt(Prompt):
     #Collect a string from the user by using the
     #quickly.prompts.string() helper function
     reponse, val = string("String select test","String select test")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         my_string = val
 
     Configuring
     #Add widgets to the conent_box member
     sp = StringPrompt(title, text, default_string)
-    sp.content_box.pack_end(my_additional_widget)
+    sp.content_box.pack_end(my_additional_widget, False, False, 5)
 
     #Modify the _entry member
     sp._entry.set_max_length(144)
 
     Extending
-    A StringPrompt is a Prompt which is gtk.Dialog
+    A StringPrompt is a Prompt which is Gtk.Dialog
 
     """
 
@@ -156,14 +160,14 @@ class StringPrompt(Prompt):
         """
 
         Prompt.__init__(self, title, text)
-        self._entry = gtk.Entry()
+        self._entry = Gtk.Entry()
         self._entry.set_text(default_value)
         self._entry.set_activates_default(True)
         self._entry.show()
         self.content_box.pack_end(self._entry, True, True, 5)
 
     def get_value(self):
-        """get_value - returns the value the user has entered into the gtk.Entry
+        """get_value - returns the value the user has entered into the Gtk.Entry
 
         """
 
@@ -178,13 +182,13 @@ def date(title = _("Choose Date"), text = _("Choose a Date:"), default_value = N
     default_value - a tuple in the form of integers for (year,month,day)
     where month is zero indexed (Jaunary is 0, December is 11)
 
-    returns a tuple of (gtk.DialogResponse, tuple)
+    returns a tuple of (Gtk.DialogResponse, tuple)
     The returnd tuple is in the form of integers for (year,month,day)
     where month is zero indexed (Jaunary is 0, December is 11)
 
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
 
     """
     dp = DatePrompt(title, text, default_value)
@@ -201,7 +205,7 @@ class DatePrompt(Prompt):
     #Collect a date from the user by using the
     #quickly.prompts.date() helper function
     reponse, val = date("Date prompt title","Date prompt message")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         my_date = val
 
     Configuring
@@ -210,10 +214,10 @@ class DatePrompt(Prompt):
     dp.content_box.pack_end(my_additional_widget)
 
     #Modify the _calendar member
-    dp._calendar.set_display_options(gtk.CALENDAR_SHOW_DAY_NAMES)
+    dp._calendar.set_display_options(Gtk.CALENDAR_SHOW_DAY_NAMES)
 
     Extending
-    A DatePrompt is a Prompt which is a gtk.Dialog.
+    A DatePrompt is a Prompt which is a Gtk.Dialog.
 
     """
 
@@ -226,7 +230,7 @@ class DatePrompt(Prompt):
 
         """
         Prompt.__init__(self, title, text)          
-        self._calendar = gtk.Calendar()
+        self._calendar = Gtk.Calendar()
         self._calendar.show()
         self.content_box.pack_end(self._calendar, True, True, 5)
 
@@ -263,11 +267,11 @@ def integer(title = _("Enter Number"), text = _("Enter an Integer Value:"),
     max_value, the highest number accepted by the spinner,
     defaults to 1000000000
 
-    returns a tuple of (gtk.DialogResponse, integer)
+    returns a tuple of (Gtk.DialogResponse, integer)
 
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
 
     """
 
@@ -280,14 +284,14 @@ def integer(title = _("Enter Number"), text = _("Enter an Integer Value:"),
 
 class IntegerPrompt(Prompt):
     """A Prompt for collecting an integer number value from user. Uses
-        a gtk.Spinner for data entry.
+        a Gtk.Spinner for data entry.
 
 
     Using
     #Collect an integer value from the user by using the
     #quickly.prompts.integer() helper function
     reponse, val = integer("Integer prompt title","Integer prompt message")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         my_date = val
 
     Configuring
@@ -299,7 +303,7 @@ class IntegerPrompt(Prompt):
     dp._spinner.set_value(20)
 
     Extending
-    An IntegerPrompt is a Prompt which is a gtk.Dialog
+    An IntegerPrompt is a Prompt which is a Gtk.Dialog
 
     """
 
@@ -311,8 +315,9 @@ class IntegerPrompt(Prompt):
         """
 
         Prompt.__init__(self, title, text)
-        adj = gtk.Adjustment(default_value,min_value,max_value,step)
-        self._spinner = gtk.SpinButton(adj,1,0)
+        adj = Gtk.Adjustment(default_value,min_value,max_value,step)
+        self._spinner = Gtk.SpinButton()
+        self._spinner.set_adjustment(adj)
         self._spinner.set_activates_default(True)
         self._spinner.show()
         self._spinner.set_numeric(True)
@@ -344,11 +349,11 @@ def decimal(title=_("Enter Price"), text=_("Choose a Price:"),
     supports a maximum of 20 decimal places. Values great than 20 will
     be converted to 20, and values less than 0 will be converted to 0
 
-    returns a tuple of (gtk.DialogResponse, number)
+    returns a tuple of (Gtk.DialogResponse, number)
 
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
 
     """
 
@@ -361,14 +366,14 @@ def decimal(title=_("Enter Price"), text=_("Choose a Price:"),
 
 class DecimalPrompt(Prompt):
     """A Prompt for collecting a decimal number value from user. Uses
-        a gtk.Spinner for data entry.
+        a Gtk.Spinner for data entry.
 
     Using
     #Collect a number from the user by using the
     #quickly.prompts.decimal() helper function
     reponse, val = decimal("Decimal prompt title","Decimal prompt message")
-    if response == gtk.RESPONSE_OK:
-        my_date = val
+    if response == Gtk.ResponseType.OK:
+        my_decimal = val
 
     Configuring
     #Add widgets to the content_box member
@@ -379,7 +384,7 @@ class DecimalPrompt(Prompt):
     dp._spinner.set_value(20.0)
 
     Extending
-    An DecimalPrompt is a Prompt which is a gtk.Dialog
+    An DecimalPrompt is a Prompt which is a Gtk.Dialog
 
 
     """
@@ -406,22 +411,24 @@ class DecimalPrompt(Prompt):
         supports a maximum of 20 decimal places. Values great than 20 will
         be converted to 20, and values less than 0 will be converted to 0
 
-        returns a tuple of (gtk.DialogResponse, number)
+        returns a tuple of (Gtk.DialogResponse, number)
     
-        gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-        the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-        (gtk.RESPONSE_DELETE_EVENT)
+        Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+        the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+        (Gtk.ResponseType.DELETE_EVENT)
 
         """
 
         Prompt.__init__(self, title, text)
 
-        self._adjustment = gtk.Adjustment(default_value,min_value,max_value,step)
+        self._adjustment = Gtk.Adjustment(default_value,min_value,max_value,step)
         if digits > 20:
             digits = 20
         if digits < 0:
             digits = 0
-        self._spinner = gtk.SpinButton(self._adjustment,1,digits)
+        self._spinner = Gtk.SpinButton()
+        self._spinner.set_adjustment(self._adjustment)
+        self._spinner.set_digits(digits)
         self._spinner.set_activates_default(True)
         self._spinner.show()
         self._spinner.set_numeric(True)
@@ -450,11 +457,11 @@ def price(title=_("Enter Price"), text=_("Choose a Price:"),
     step - set the incriments for each click of the spinner buttons,
     defaults to 1
 
-    returns a tuple of (gtk.DialogResponse, number)
+    returns a tuple of (Gtk.DialogResponse, number)
 
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
 
     """
 
@@ -468,13 +475,13 @@ def price(title=_("Enter Price"), text=_("Choose a Price:"),
 class PricePrompt(DecimalPrompt):
     """A Prompt for collecting a decimal number value from the user,
         formatted with two decimal places appropriate for entering
-        a currence ammount. Uses a gtk.Spinner for data entry.
+        a currence ammount. Uses a Gtk.Spinner for data entry.
 
     Using
     #Collect a number from the user by using the
     #quickly.prompts.price() helper function
     reponse, val = price("Price prompt title","Price prompt message")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         my_date = val
 
     Configuring
@@ -486,7 +493,7 @@ class PricePrompt(DecimalPrompt):
     pp._spinner.set_value(20.00)
 
     Extending
-    An PricePrompt is Decimal Prompt which is a Prompt which is a gtk.Dialog
+    An PricePrompt is Decimal Prompt which is a Prompt which is a Gtk.Dialog
 
 
     """
@@ -510,11 +517,11 @@ class PricePrompt(DecimalPrompt):
         step - set the incriments for each click of the spinner buttons,
         defaults to 1
 
-        returns a tuple of (gtk.DialogResponse, number)
+        returns a tuple of (Gtk.DialogResponse, number)
 
-        gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-        the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-        (gtk.RESPONSE_DELETE_EVENT)
+        Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+        the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+        (Gtk.ResponseType.DELETE_EVENT)
 
         """
 
@@ -534,10 +541,10 @@ def yes_no(title = _("Choose Yes or No"), text = "", yes="", no=""):
     yes - a string that is a verb representing the Yes action
     no - a string that is a verb representing the No action
 
-    returns a gtk.DialogResponse
-    gtk.RESPONSE_YES means the user clicked the "YES" button, otherwise
-    gtk.RESPONSE_NO means the user clicked the "NO" button, otherwise
-    the user dismissed the dialogv(gtk.RESPONSE_DELETE_EVENT)
+    returns a Gtk.DialogResponse
+    Gtk.ResponseType.YES means the user clicked the "YES" button, otherwise
+    Gtk.ResponseType.NO means the user clicked the "NO" button, otherwise
+    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)
 
     """
     yn = YesNoPrompt(title,text,yes,no)
@@ -545,7 +552,7 @@ def yes_no(title = _("Choose Yes or No"), text = "", yes="", no=""):
     yn.destroy()
     return response
 
-class YesNoPrompt(gtk.Dialog):
+class YesNoPrompt(Gtk.Dialog):
     """A prompt to collect a user choice between two options,
         one "yes" and one "no", though typically the button labels
         should be set as verbs.
@@ -554,7 +561,7 @@ class YesNoPrompt(gtk.Dialog):
     #Collect a response from the user using the
     #quickly.prompts.yes_no() helper function
     reponse = decimal(title,message,"Do it", "Don't do it")
-    if response == gtk.RESPONSE_YES:
+    if response == Gtk.ResponseType.YES:
         yes = True
     else:
         yes = False
@@ -565,11 +572,11 @@ class YesNoPrompt(gtk.Dialog):
     dp.content_box.pack_end(my_additional_widget)
 
     #add a widget to the response by creating it and
-    #passing it in with a Gtk.RESPONSE_ID
+    #passing it in with a Gtk.ResponseType.ID
     dp.add_action_widget(new_widget, response_id)
 
     Extending
-    An YesNoPrompt is a gtk.Dialog
+    An YesNoPrompt is a Gtk.Dialog
 
     """
 
@@ -585,37 +592,37 @@ class YesNoPrompt(gtk.Dialog):
 
         """
 
-        gtk.Dialog.__init__(self, title, None, gtk.DIALOG_MODAL)
+        Gtk.Dialog.__init__(self, title, None, Gtk.DialogFlags.MODAL)
 
         if no == "":
-            no_button = gtk.Button(stock=gtk.STOCK_NO)
+            no_button = Gtk.Button(stock=Gtk.STOCK_NO)
         else:
-            no_button = gtk.Button(label=no)
-        self.add_action_widget(no_button,gtk.RESPONSE_NO)
+            no_button = Gtk.Button(label=no, use_underline=True)
+        self.add_action_widget(no_button,Gtk.ResponseType.NO)
         no_button.show()
 
         if yes == "":
-            yes_button = gtk.Button(stock=gtk.STOCK_YES)
+            yes_button = Gtk.Button(stock=Gtk.STOCK_YES)
         else:
-            yes_button = gtk.Button(label=yes)
-        self.add_action_widget(yes_button,gtk.RESPONSE_YES)
+            yes_button = Gtk.Button(label=yes, use_underline=True)
+        self.add_action_widget(yes_button,Gtk.ResponseType.YES)
         yes_button.show()
-        yes_button.set_flags(gtk.CAN_DEFAULT)
+        yes_button.set_can_default(True)
 
 
-        self.set_has_separator(False)
+        #self.set_has_separator(False)
         content_area = self.get_content_area()
         content_area.set_border_width(5)
-        self.set_default_response(gtk.RESPONSE_YES)
+        self.set_default_response(Gtk.ResponseType.YES)
 
-        self.content_box = gtk.HBox(False, 10)
-        img = gtk.Image()
-        img.set_from_stock(gtk.STOCK_DIALOG_QUESTION,gtk.ICON_SIZE_DIALOG)
-        self.content_box.pack_start(img)
-        label = gtk.Label(text)
+        self.content_box = Gtk.HBox(False, 10)
+        img = Gtk.Image()
+        img.set_from_stock(Gtk.STOCK_DIALOG_QUESTION,Gtk.IconSize.DIALOG)
+        self.content_box.pack_start(img, False, False, 5)
+        label = Gtk.Label(text)
         label.set_line_wrap(True)
         self.content_box.pack_start(label,False, False, 5)
-        content_area.pack_start(self.content_box)
+        content_area.pack_start(self.content_box, False, False, 5)
         self.content_box.show()
         label.show()
         img.show()
@@ -628,13 +635,13 @@ def warning(title = _("Warning"), text = ""):
     title - a string to be the title of the dialog
     text - a string describing the warning
 
-    returns a gtk.DialogResponse
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user dismissed the dialogv(gtk.RESPONSE_DELETE_EVENT)
+    returns a Gtk.DialogResponse
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)
 
     """
 
-    w = Alert(title,text,gtk.STOCK_DIALOG_WARNING)
+    w = Alert(title,text,Gtk.STOCK_DIALOG_WARNING)
     response = w.run()
     w.destroy()
     return response
@@ -647,13 +654,13 @@ def error(title = _("Error"), text = ""):
     title - a string to be the title of the dialog
     text - a string describing the error
 
-    returns a gtk.DialogResponse
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user dismissed the dialogv(gtk.RESPONSE_DELETE_EVENT)
+    returns a Gtk.DialogResponse
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)
 
     """
 
-    e = Alert(title,text,gtk.STOCK_DIALOG_ERROR)
+    e = Alert(title,text,Gtk.STOCK_DIALOG_ERROR)
     response = e.run()
     e.destroy()
     return response
@@ -667,18 +674,18 @@ def info(title = _("Information"), text = ""):
     title - a string to be the title of the dialog
     text - a string providing the information
 
-    returns a gtk.DialogResponse
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user dismissed the dialogv(gtk.RESPONSE_DELETE_EVENT)
+    returns a Gtk.DialogResponse
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)
 
     """
 
-    i = Alert(title,text,gtk.STOCK_DIALOG_INFO)
+    i = Alert(title,text,Gtk.STOCK_DIALOG_INFO)
     response = i.run()
     i.destroy()
     return response
 
-class Alert(gtk.Dialog):
+class Alert(Gtk.Dialog):
     """Displays an icon, a message, and an OK button to users.
     Used by quickly.prompts.info(), quickly.prompts.warning(),
     and quickly.prompts.error(). 
@@ -690,37 +697,37 @@ class Alert(gtk.Dialog):
     Configuring
     #Add widgets to the content_box member
     alert = Alert(title, text, image)
-    alert.content_box.pack_end(my_additional_widget)
+    alert.content_box.pack_end(my_additional_widget, False, False, 5)
 
-    #change the image by passing in a stock gtk image
+    #change the image by passing in a stock Gtk image
     alert.set_image(stock_image)
 
     Extending
-    An Alert is a gtk.Dialog.
+    An Alert is a Gtk.Dialog.
 
     """
 
     def __init__(self,title="",text="",image=None):
-        gtk.Dialog.__init__(self, title,None,gtk.DIALOG_MODAL,(gtk.STOCK_OK, gtk.RESPONSE_OK))
-        self.set_has_separator(False)
+        Gtk.Dialog.__init__(self, title,None,Gtk.DialogFlags.MODAL,(Gtk.STOCK_OK, Gtk.ResponseType.OK))
+        #self.set_has_separator(False)
         content_area = self.get_content_area()
         content_area.set_border_width(5)
-        self.set_default_response(gtk.RESPONSE_OK)
+        self.set_default_response(Gtk.ResponseType.OK)
 
-        self.content_box = gtk.HBox(False, 10)
-        label = gtk.Label(text)
+        self.content_box = Gtk.HBox(False, 10)
+        label = Gtk.Label(text)
         label.set_line_wrap(True)
-        self._image = gtk.Image()
-        self._image.set_from_stock(image,gtk.ICON_SIZE_DIALOG)
+        self._image = Gtk.Image()
+        self._image.set_from_stock(image,Gtk.IconSize.DIALOG)
         self.content_box.pack_start(self._image, False, False, 5)
         self.content_box.pack_end(label,False, False, 5)
-        content_area.pack_start(self.content_box)
+        content_area.pack_start(self.content_box, False, False, 5)
         self.content_box.show()
         label.show()
         self._image.show()
 
     def set_image(self, image):
-        self._image.set_from_stock(image,gtk.ICON_SIZE_DIALOG)        
+        self._image.set_from_stock(image,Gtk.IconSize.DIALOG)        
     
 
 def save_image_file(title=_("Choose an Image"),path=None):
@@ -731,10 +738,10 @@ def save_image_file(title=_("Choose an Image"),path=None):
     path - a string providing a path to a directory where the
     dialog should start. Defaults to Pictures directory.
 
-    returns a gtk.DialogResponse
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
+    returns a Gtk.DialogResponse
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
     the user clicked "Cancel" or the userdismissed the 
-    dialogv(gtk.RESPONSE_DELETE_EVENT)
+    dialogv(Gtk.ResponseType.DELETE_EVENT)
 
     """
 
@@ -745,7 +752,7 @@ def save_image_file(title=_("Choose an Image"),path=None):
     return (response, value)
 
 
-class ImageDialog(gtk.FileChooserDialog):
+class ImageDialog(Gtk.FileChooserDialog):
     """A base class for OpenImageDialog and SaveImageDialog
 
     Sets up typical mime types and file name patterns suitable
@@ -761,10 +768,10 @@ class ImageDialog(gtk.FileChooserDialog):
         """Create an ImageDialog.
 
         arguments:
-        action - a file chooser action, either gtk.FILE_CHOOSER_ACTION_SAVE
-        or gtk.FILE_CHOOSER_ACTION_OPEN
-        button - a gtk stock button for the intended action, either
-        gtk.STOCK_SAVE or gtk.STOCK_OPEN
+        action - a file chooser action, either Gtk.FILE_CHOOSER_ACTION_SAVE
+        or Gtk.FILE_CHOOSER_ACTION_OPEN
+        button - a Gtk stock button for the intended action, either
+        Gtk.STOCK_SAVE or Gtk.STOCK_OPEN
 
         keyword arguments:
         title - a title for the dialog, defaults to an empty string
@@ -773,24 +780,24 @@ class ImageDialog(gtk.FileChooserDialog):
 
         """
 
-        gtk.FileChooserDialog.__init__(self,title,
+        Gtk.FileChooserDialog.__init__(self,title,
                                             None,
                                             action,
-                                            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                            button, gtk.RESPONSE_OK))
+                                            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                                            button, Gtk.ResponseType.OK))
 
-        self.set_default_response(gtk.RESPONSE_OK)
+        self.set_default_response(Gtk.ResponseType.OK)
 
         if path == None:
-            path = glib.get_user_special_dir(glib.USER_DIRECTORY_PICTURES)        
+            path = GLib.get_user_special_dir(GLib.USER_DIRECTORY_PICTURES)        
         self.set_current_folder(path)
 
-        self._filter = gtk.FileFilter()
+        self._filter = Gtk.FileFilter()
         self._filter.set_name("All files")
         self._filter.add_pattern("*")
         self.add_filter(self._filter)
 
-        self._filter = gtk.FileFilter()
+        self._filter = Gtk.FileFilter()
         self._filter.set_name("Images")
         self._filter.add_mime_type("image/png")
         self._filter.add_mime_type("image/jpeg")
@@ -811,7 +818,7 @@ class SaveImageDialog(ImageDialog):
     #Collect a location using the quickly.prompts.save_image_file()
     #helper function
     response, path = save_image_file(title)
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         save_to_path = path
 
     Configuring
@@ -820,7 +827,7 @@ class SaveImageDialog(ImageDialog):
     sid._filter.add_pattern("*.svg")
 
     Extending
-    A SaveImageDialog is an ImageDialog which is a gtk.FileChooserDialog
+    A SaveImageDialog is an ImageDialog which is a Gtk.FileChooserDialog
 
     """
 
@@ -834,7 +841,7 @@ class SaveImageDialog(ImageDialog):
 
         """
 
-        ImageDialog.__init__(self,gtk.FILE_CHOOSER_ACTION_SAVE, gtk.STOCK_SAVE, title,path)
+        ImageDialog.__init__(self,Gtk.FileChooserAction.SAVE, Gtk.STOCK_SAVE, title,path)
 
 class OpenImageDialog(ImageDialog):
     """
@@ -844,7 +851,7 @@ class OpenImageDialog(ImageDialog):
     #Collect a location using the quickly.prompts.open_image_file()
     #helper function
     response, path = open_image_file(title)
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         path_to_image = path
 
     Configuring
@@ -853,7 +860,7 @@ class OpenImageDialog(ImageDialog):
     sid._filter.add_pattern("*.svg")
 
     Extending
-    A SaveImageDialog is an ImageDialog which is a gtk.FileChooserDialog
+    A SaveImageDialog is an ImageDialog which is a Gtk.FileChooserDialog
 
     """
 
@@ -866,7 +873,7 @@ class OpenImageDialog(ImageDialog):
         ~/Pictures
 
         """
-        ImageDialog.__init__(self,gtk.FILE_CHOOSER_ACTION_OPEN, gtk.STOCK_OPEN, title,path)
+        ImageDialog.__init__(self,Gtk.FileChooserAction.OPEN, Gtk.STOCK_OPEN, title,path)
 
 def open_image_file(title=_("Choose an Image"),path=None):
     """open_image_file - prompts the user to choose an image file
@@ -876,10 +883,10 @@ def open_image_file(title=_("Choose an Image"),path=None):
     path - a string providing a path to a directory where the
     dialog should start. Defaults to Pictures directory.
 
-     returns a tuple of (gtk.DialogResponse, str)
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+     returns a tuple of (Gtk.DialogResponse, str)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
     The str is the path to the image chosen by the user, if any.
 
 
@@ -900,10 +907,10 @@ def choose_directory(title=_("Choose a Directory"),path=None):
     dialog should start.
 
 
-    returns a tuple of (gtk.DialogResponse, str)
-    gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
-    (gtk.RESPONSE_DELETE_EVENT)
+    returns a tuple of (Gtk.DialogResponse, str)
+    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
+    the user cancelled (Gtk.ResponseType.CANCEL) or dismissed the dialog
+    (Gtk.ResponseType.DELETE_EVENT)
     The str is the path to the directory chosen by the user, if any.
 
     """
@@ -914,7 +921,7 @@ def choose_directory(title=_("Choose a Directory"),path=None):
     dcd.destroy()
     return (response, value)
 
-class DirectoryChooserDialog(gtk.FileChooserDialog):
+class DirectoryChooserDialog(Gtk.FileChooserDialog):
     """A Dialog to prompt the user to choose a directory path.
 
     Using
@@ -922,13 +929,13 @@ class DirectoryChooserDialog(gtk.FileChooserDialog):
     quickly.prompts.choose_directory(title)
 
     Configuring
-    #A DirectoryChooseDialog is a gtk.FileChooserDialog, so you can
-    #use gtk.FileChooseDialog members
+    #A DirectoryChooseDialog is a Gtk.FileChooserDialog, so you can
+    #use Gtk.FileChooseDialog members
     dcd = DirectoryChooserDialog(title)
     dcd.set_local_only(False)
 
     Extending
-    #A DirectoryChooseDialog is a gtk.FileChooserDialog
+    #A DirectoryChooseDialog is a Gtk.FileChooserDialog
 
     """
 
@@ -943,12 +950,12 @@ class DirectoryChooserDialog(gtk.FileChooserDialog):
 
         """
 
-        gtk.FileChooserDialog.__init__(self, title,
+        Gtk.FileChooserDialog.__init__(self, title,
                                     None,
-                                    gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                                    (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                    gtk.STOCK_OPEN, gtk.RESPONSE_OK))
-        self.set_default_response(gtk.RESPONSE_OK)
+                                    Gtk.FileChooserAction.SELECT_FOLDER,
+                                    (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                                    Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
+        self.set_default_response(Gtk.ResponseType.OK)
         if path is not None:
             self.set_current_folder(path)
 
@@ -962,63 +969,63 @@ if __name__ == "__main__":
 
     #the rest of values to test for
     response, val = choose_directory("directory choose test")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
-    print "selected directory was " + val
+    print "selected directory was " + str(val)
 
     response, val = open_image_file("image open test")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "selected locations was " + str(val)
 
     response, val = save_image_file("image save test")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "selected locations was " + str(val)
 
     reponse, val = string("String select test","String select test")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "string was " + str(val)
 
     reponse, val = date("Date select test","Date select test")
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "date was " + str(val)
 
     reponse, val = integer("Integer select test","Integer select test",default_value=20)
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "integer was " + str(val)
 
-    reponse, val = decimal("Price select test","Price select test",default_value=20,digits=5)
-    if response == gtk.RESPONSE_OK:
+    reponse, val = decimal("Decimal select test","Decimal select test",default_value=20,digits=5)
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "decimal was " + str(val)
 
     reponse, val = price("Price select test","Price select test",default_value=20)
-    if response == gtk.RESPONSE_OK:
+    if response == Gtk.ResponseType.OK:
         print "response was OK"
     else:
         print "response was not OK"
     print "price was " + str(val)
 
     response = yes_no("Yes/No Test","Yes/No Test", "_Yes Verb","_No Verb")
-    if response == gtk.RESPONSE_YES:
+    if response == Gtk.ResponseType.YES:
         print "response was yes"
 
 
