@@ -13,8 +13,6 @@
 #with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 
-import gtk
-import gobject
 from grid_column import StringColumn, CurrencyColumn, CheckColumn
 from grid_column import IntegerColumn, TagsColumn, DateColumn
 
