@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 ### BEGIN LICENSE
 # Copyright (C) 2010 Rick Spencer rick.spencer@canonical.com
@@ -13,10 +14,10 @@
 #You should have received a copy of the GNU General Public License along 
 #with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
-"""A gtk.TreeView for Dictionaries
-Displays and persists data in a gtk.TreeView. Handles the
-set up of the gtk.TreeView, gtk.ListModel, gtk.TreeViewColumns,
-and gtk.CellRenderers.
+"""A Gtk.TreeView for Dictionaries
+Displays and persists data in a Gtk.TreeView. Handles the
+set up of the Gtk.TreeView, Gtk.ListModel, Gtk.TreeViewColumns,
+and Gtk.CellRenderers.
 
 Using
 #create a dictionary if you don't already have one
@@ -39,7 +40,7 @@ dg = DictionaryGrid(dictionaries=dicts,keys=keys)
 hints = {"price": StringColumn}
 dg = CouchGrid(dictionaries=dicts,keys=keys, type_hints = hints)
 
-#A CouchGrid is gtk.TreeView, so you can use gtk.TreeView members
+#A CouchGrid is Gtk.TreeView, so you can use Gtk.TreeView members
 dg.get_column(0).set_title("Price")
 
 #Use the selection-changed signal and read from the DictionaryGrid
@@ -66,13 +67,17 @@ how the data is being displayed, etc...
 
 """
 
-import gtk
-import gobject
+import sys
+
+from gi.repository import GObject
+from gi.repository import Gtk
 import conventions
-from quickly.widgets.grid_column import StringColumn
+from grid_column import StringColumn
 from grid_column import CheckColumn
 
-class DictionaryGrid(gtk.TreeView):
+class DictionaryGrid(Gtk.TreeView):
+    __gtype_name__ = "DictionaryGrid"
+    
     def __init__(self, dictionaries=None, editable = False, keys=None, type_hints=None):
         """
         Creates a new DictionaryGrid
@@ -99,7 +104,7 @@ class DictionaryGrid(gtk.TreeView):
 
         """
 
-        gtk.TreeView.__init__(self)
+        Gtk.TreeView.__init__(self)
         self.list_store = None
         self.unfiltered_store = None
         self._keys = keys
@@ -112,7 +117,7 @@ class DictionaryGrid(gtk.TreeView):
             self._type_hints = {}
         else:
             self._type_hints = type_hints
-        self.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
+        self.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
         self._refresh_treeview()
 
         #signal handlers to track selection in the treeview
@@ -181,10 +186,17 @@ class DictionaryGrid(gtk.TreeView):
 
     @editable.setter
     def editable(self, editable):
-        self._editable = editable
-
         #refresh the treeview if possible
-        self._refresh_treeview()
+        #self._refresh_treeview()
+
+        # Refreshing the treeview has no benefits but many negative
+        # side effects. Better to loop over the columns, setting the property
+        # on each renderer. The columns should probably expose this property
+        # themselves, but for now this works. 
+
+        for column in self.get_columns():
+            column.set_editable(editable)
+        self._editable = editable
 
     @property
     def columns(self):
@@ -241,7 +253,7 @@ class DictionaryGrid(gtk.TreeView):
     def _refresh_treeview(self):
         """
         _refresh_treeview: internal function to handle rebuilding
-        the gtk.TreeView along with columns and cell renderers.. 
+        the Gtk.TreeView along with columns and cell renderers.. 
 
         _refresh_treeview is not typically called directly,
         but may be useful to override in subclasses.
@@ -324,6 +336,8 @@ class DictionaryGrid(gtk.TreeView):
 
         #get the selected rows in the ListStore
         selection = self.get_selection()
+        if selection is None:
+            return []
         model, model_rows = selection.get_selected_rows()
         
         rows = [] #list of rows to return
@@ -340,7 +354,7 @@ class DictionaryGrid(gtk.TreeView):
         """
         remove_selected_rows: removes the rows currently selected
         in the TreeView UI from the TreeView as well as the backing
-        gtk.ListStore.
+        Gtk.ListStore.
 
         """
 
@@ -351,11 +365,11 @@ class DictionaryGrid(gtk.TreeView):
             return
 
         #store the last selected row to reselect after removal
-        next_to_select = rows[-1][0] + 1 - len(rows)
+        next_to_select = rows[-1].get_indices()[0] + 1 - len(rows)
         
         #loop through and remove
 
-        if type(model) is not gtk.ListStore:
+        if type(model) is not Gtk.ListStore:
             iters = [model.get_model().get_iter(path) for path in rows]
             store_iters = []
 
@@ -421,8 +435,8 @@ class DictionaryGrid(gtk.TreeView):
             
         #create the liststore with the designated types
         #the last column is always for storing the backing dict
-        col_types.append(gobject.TYPE_PYOBJECT)
-        self.list_store = gtk.ListStore(*col_types)
+        col_types.append(GObject.TYPE_PYOBJECT)
+        self.list_store = Gtk.ListStore(*col_types)
 
         for c in self.get_columns():
             self.__last_sorted_col = None
@@ -449,11 +463,11 @@ class DictionaryGrid(gtk.TreeView):
                 self.__last_sorted_col.set_sort_indicator(False)
         self.__last_sorted_col = column
 
-    __gsignals__ = {'cell-edited' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
-        (gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT)),
+    __gsignals__ = {'cell-edited' : (GObject.SignalFlags.RUN_LAST, GObject.TYPE_NONE,
+        (GObject.TYPE_PYOBJECT,GObject.TYPE_PYOBJECT,GObject.TYPE_PYOBJECT,GObject.TYPE_PYOBJECT,GObject.TYPE_PYOBJECT)),
 
-            'selection-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
-            (gobject.TYPE_PYOBJECT,))
+            'selection-changed' : (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE,
+            (GObject.TYPE_PYOBJECT,))
         }
 
 def __show_selected(widget, selected_rows, data=None):
@@ -471,21 +485,21 @@ def __on_edited(widget, cell, row, key,  new_value, row_dict, tv):
     tv.get_buffer().set_text(string)
 
 if __name__ == "__main__":
-    """creates a test CouchGrid if called directly"""
+    """creates a test DictionaryGrid if called directly"""
 
     dicts = [{"key?": True, "price":0.00,"tags" : "aaa bbb ccc","_foo":"bar","bing count":20},
                  {"ID": 11, "key?": False, "price":2.00,"tags" : "bbb ccc ddd","_foo":"bar"},
                  {"key?": True, "price":33.00,"tags" : "ccc ddd eee","_foo":"bar","bing count":15},
                  {"ID": 3, "tags" : "ddd eee fff","_foo":"bar"},
                  {"ID": 4, "price":5.00,"_foo":"bar"}]
-    #create and show a test window
-    win = gtk.Window(gtk.WINDOW_TOPLEVEL)
+    #create and show a test windowp
+    win = Gtk.Window()
     win.set_title("DictionaryGrid Test Window")
-    win.connect("destroy",gtk.main_quit)
+    win.connect("destroy",Gtk.main_quit)
     win.show()
 
     #create a top level container
-    vbox = gtk.VBox(False, False)
+    vbox = Gtk.VBox(False, False)
     vbox.show()
     win.add(vbox)
 
@@ -497,19 +511,19 @@ if __name__ == "__main__":
 
     #show the control, add it to the window, and run the main loop
     grid.show()
-    vbox.pack_start(grid, False, True)
+    vbox.pack_start(grid, False, False, 0)
 
     #create a test display area
-    hbox = gtk.HBox(False, 5)
+    hbox = Gtk.HBox(False, 5)
     hbox.show()
-    tv = gtk.TextView()
+    tv = Gtk.TextView()
     tv.show()
     grid.connect("selection-changed",__show_selected, tv)
     grid.connect("cell-edited",__on_edited, tv)
 
-    hbox.pack_start(tv, False, False)
-    vbox.pack_end(hbox, False, False)
+    hbox.pack_start(tv, False, False, 0)
+    vbox.pack_end(hbox, False, False, 0)
 
     #run the test app
-    gtk.main()
+    Gtk.main()
 
