@@ -23,8 +23,8 @@ DictionaryGrid documentation for how to use type hints and conventions
 to control the type of column used for a key in a dictionary.
 
 Customizing
-The column types in this module are all descendants of gtk.TreeView, so
-you can use all of the gtk.TreeView methods and properties to control
+The column types in this module are all descendants of Gtk.TreeView, so
+you can use all of the Gtk.TreeView methods and properties to control
 how a grid column looks or works.
 
 #Find a grid column and change the title
@@ -34,7 +34,7 @@ for c in my_dictionary_grid.get_columns():
 
 Extending
 To display data in a column with a string, such as to display words and
-numbers, you should extend StringColumn. Otherwise, extend gtk.TreeView
+numbers, you should extend StringColumn. Otherwise, extend Gtk.TreeView
 directly. In either case, you will need to implement a set of functions.
 
 A Grid Column must track two different data, a "real" value, which is tracked
@@ -56,7 +56,7 @@ default_display_val(self) - reutrn the value to display in the case where
 a row does not contain a key, value pair for the specified column. For example
 StringColumn returns an empty string ("")
 
-A new column type will often require a specially configured gtk.CellRenderer.
+A new column type will often require a specially configured Gtk.CellRenderer.
 If you are deriving from StringColumn, but are using a custom renderer,
 you need to override the _initialize_renderer method, and set the 
 columns renderer property to the renderer. You should also connect the 
@@ -68,8 +68,8 @@ For instance, a CurrencyColumn has the following implemention for
 _initialize_renderer:
 
     def _initialize_renderer( self, editable, index ):
-        self.renderer = gtk.CellRendererSpin()
-        adj = gtk.Adjustment(0,-10000000000,10000000000,1)
+        self.renderer = Gtk.CellRendererSpin()
+        adj = Gtk.Adjustment(0,-10000000000,10000000000,1)
         self.renderer.set_property("adjustment", adj)
         self.renderer.set_property("editable", editable)
         self.renderer.set_property("digits",2)
@@ -89,26 +89,69 @@ default_filter = grid_filter.NumericFilterBox
 """
 
 
-
 import sys
 import datetime
 import gettext
 from gettext import gettext as _
 gettext.textdomain('quickly-widgets')
 
-try:
-    import pygtk
-    pygtk.require("2.0")
-    import gtk
-    import gobject
-    import grid_filter
+import grid_filter
+
+from gi.repository import GObject
+from gi.repository import Gtk
+from gi.repository import Gdk
 
 
-except Exception, inst:
-    print "some dependencies for GridFilter are not available"
-    raise inst
+class GridColumn( Gtk.TreeViewColumn ):
+    """GridColumn - Base class that provides features that is important
+    to all columns used in a DictionaryGrid or decendants. Currently
+    it's useful only to StringColumn and CheckColumn, but should make it
+    easier to make new "top-level" column types.  
+    """
+
+    def __init__(self, key, index, dictionary_index, renderer, editable=True, format_function = None ):
+        Gtk.TreeViewColumn.__init__(self, key, renderer, text=index)
+
+        self.set_clickable(True)
+        self.set_resizable(True)
+
+        self.index = index
+        self.key = key
+        self.dictionary_index = dictionary_index
+        # Why should list_store be set to None? 
+        self.list_store = None
+
+
+        self.connect('clicked', self.sort_rows)
+
+
+    def sort_rows(self, widget):
+        sort_order = widget.get_sort_order()                
+        
+        rows = [tuple(r) + (i,) for i, r in enumerate(self.list_store)]
+
+        # Sort opposite of last time 
+        if sort_order == Gtk.SortType.ASCENDING:
+            sort_order = Gtk.SortType.DESCENDING
+        else:
+            sort_order = Gtk.SortType.ASCENDING
+
+        self.set_sort_order(sort_order)
+        self.set_sort_indicator(True)
+        
+        if sort_order == Gtk.SortType.ASCENDING:
+            rows.sort(self._sort_ascending)
+        else:
+            rows.sort(self._sort_descending)
+
+        # Where does self.list_store come from? 
+        self.list_store.set_sort_column_id(self.index, sort_order)
+
+    def set_editable(self, editable):
+        self.renderer.set_property("editable", editable)
+
+class StringColumn( GridColumn ):
 
-class StringColumn( gtk.TreeViewColumn ):
     """StringColumn - Displays strings and tracks data as string.
     Uses a CellRendererText for display and editing. Not typically created
     directly in code, but rather created by a DictionaryGrid or descendant.
@@ -117,7 +160,7 @@ class StringColumn( gtk.TreeViewColumn ):
 
     """
 
-    column_type = gobject.TYPE_STRING
+    column_type = GObject.TYPE_STRING
     __sort_order = None
     default_filter = grid_filter.StringFilterBox
     def __init__(self, key, index, dictionary_index, editable=True, format_function = None ):
@@ -140,47 +183,13 @@ class StringColumn( gtk.TreeViewColumn ):
 
         """
 
-        self.index = index
-        self.key = key
-        self.list_store = None
-        self.dictionary_index = dictionary_index
+
         self._initialize_renderer(editable, index)
-        
-        gtk.TreeViewColumn.__init__( self, key, self.renderer, text=index)
+        GridColumn.__init__( self, key, index, dictionary_index, self.renderer, editable, format_function)
+
         if format_function is not None:
             self.set_cell_data_func(self.renderer, self._on_format, format_function)
 
-        self.set_clickable(True)
-        self.connect('clicked', self.sort_rows)
-        self.set_resizable(True)
-    
-    def sort_rows(self, widget):
-        """sort_rows - when called, the DictionaryGrid will resort
-        from this column. The state of the sort button in the header
-        will determine the sort order.
-        
-        """
-
-        sort_order = widget.get_sort_order()                
-        
-        rows = [tuple(r) + (i,) for i, r in enumerate(self.list_store)]
-        if sort_order == gtk.SORT_ASCENDING:
-            sort_order = gtk.SORT_DESCENDING
-
-        else:
-            sort_order = gtk.SORT_ASCENDING
-
-        self.set_sort_indicator(True)
-        self.set_sort_order(sort_order)
-        
-        if sort_order == gtk.SORT_ASCENDING:
-            rows.sort(self._sort_ascending)
-        else:
-            rows.sort(self._sort_descending)
-
-        self.list_store.reorder([r[-1] for r in rows])
-
-
     def _sort_ascending(self, x, y):
         """_sort_ascending - internal sort function that sorts two values
         in the column from least value to greatest value. 
@@ -234,7 +243,7 @@ class StringColumn( gtk.TreeViewColumn ):
         cell_renderer - a reference to the specific cell_renderer that is
         formatting the string
 
-        tree_model - the gtk.ListStore that is the backing data for the
+        tree_model - the Gtk.ListStore that is the backing data for the
         DictionaryGrid that contains the column.
 
         iter - an iterator that references the row of the the DictionaryGrid
@@ -261,8 +270,7 @@ class StringColumn( gtk.TreeViewColumn ):
 
         """
 
-        self.renderer = gtk.CellRendererText()
-        self.renderer.mode = gtk.CELL_RENDERER_MODE_EDITABLE
+        self.renderer = Gtk.CellRendererText()
         self.renderer.set_property("editable", editable)
         self.renderer.connect("edited", self._cell_edited)
   
@@ -327,14 +335,14 @@ class StringColumn( gtk.TreeViewColumn ):
         return ""
 
 class CurrencyColumn( StringColumn ):
-    """CurrencyColumn - display data in currency format. Uses a gtk.Spinner
+    """CurrencyColumn - display data in currency format. Uses a Gtk.Spinner
     to display data and support editing if enabled. Store real values as float.
 
     Inherits from StringColumn.
 
     """
 
-    column_type = gobject.TYPE_STRING
+    column_type = GObject.TYPE_STRING
     default_filter = grid_filter.NumericFilterBox
     def __init__(self, key, index,dictionary_index, editable=True ):
         """Creates a CurrencyColumn
@@ -367,8 +375,8 @@ class CurrencyColumn( StringColumn ):
 
         """
 
-        self.renderer = gtk.CellRendererSpin()
-        adj = gtk.Adjustment(0,-10000000000,10000000000,1)
+        self.renderer = Gtk.CellRendererSpin()
+        adj = Gtk.Adjustment(0,-10000000000,10000000000,1)
         self.renderer.set_property("adjustment", adj)
         self.renderer.set_property("editable", editable)
         self.renderer.set_property("digits",2)
@@ -404,21 +412,7 @@ class CurrencyColumn( StringColumn ):
         try:
             return str(float(val))
         except:
-            return ""        """Creates a CurrencyColumn
-
-        Arguments:
-        key - the key from the dict for the row. Also used as the title for the
-        column by default.
-
-        index - the position of the column in the grid.
-
-        dictionary_index - the index in the ListStore where the dictionary
-        for the row is stored. Typically len(dict).
-
-        editable - False if the column does not allow the user to edit the
-        values in the column. Defaults to True.
-
-        """
+            return ""
 
 
     def real_val(self, val):
@@ -495,19 +489,19 @@ class TagsColumn( StringColumn ):
 
     """
 
-    column_type = gobject.TYPE_STRING
+    column_type = GObject.TYPE_STRING
     default_filter = grid_filter.TagsFilterBox
 
 
 class IntegerColumn( StringColumn ):
-    """IntegerColumn - display data in Integer format. Uses a gtk.Spinner
+    """IntegerColumn - display data in Integer format. Uses a Gtk.Spinner
     to display data and support editing if enabled. Store real values as int.
 
     Inherits from StringColumn.
 
     """
 
-    column_type = gobject.TYPE_STRING
+    column_type = GObject.TYPE_STRING
     default_filter = grid_filter.IntegerFilterBox
 
     def __init__(self, key, index, dictionary_index, editable=True ):
@@ -530,8 +524,8 @@ class IntegerColumn( StringColumn ):
         StringColumn.__init__( self, key, index, dictionary_index, editable)
 
     def _initialize_renderer( self, editable, index ):
-        self.renderer = gtk.CellRendererSpin()
-        adj = gtk.Adjustment(0,-10000000000,10000000000,1)
+        self.renderer = Gtk.CellRendererSpin()
+        adj = Gtk.Adjustment(0,-10000000000,10000000000,1)
         self.renderer.set_property("adjustment", adj)
         self.renderer.set_property("editable", editable)
         self.renderer.connect("edited", self._cell_edited)
@@ -638,14 +632,14 @@ class IntegerColumn( StringColumn ):
             return 1
 
 
-class CheckColumn( gtk.TreeViewColumn ):
+class CheckColumn( GridColumn ):
     """CheckColumn - display data as checkboxes. Store real values as bool.
 
-    Inherits from gtk.TreeViewColumn.
+    Inherits from Gtk.TreeViewColumn.
 
     """
 
-    column_type = gobject.TYPE_INT
+    column_type = GObject.TYPE_INT
     default_filter = grid_filter.CheckFilterBox
 
     def __init__(self, key, index, dictionary_index, editable=True, format_function = None ):
@@ -665,44 +659,17 @@ class CheckColumn( gtk.TreeViewColumn ):
 
         format_function - and optional function to handle formatting of
         of the string to display. Defaults to None.
-
         """
 
-        self.index = index
-        self.key = key
+        # self.key is set in GridColumn, but needs to be set for tests to pass. Fix.
+
+        self.key = key  
         self._initialize_renderer(editable, index)
-        self.list_store = None
-        self.dictionary_index = dictionary_index
+        GridColumn.__init__( self, key, index, dictionary_index, self.renderer, editable, format_function)
 
-        gtk.TreeViewColumn.__init__( self, key, self.renderer)
-
-        self.set_clickable(True)
-        self.connect('clicked', self.sort_rows)
         self.set_cell_data_func(self.renderer, self._on_format)
         self.extra_format_function = format_function
 
-        self.set_resizable(True)
-
-    def sort_rows(self, widget):
-        sort_order = widget.get_sort_order()                
-        
-        rows = [tuple(r) + (i,) for i, r in enumerate(self.list_store)]
-        if sort_order == gtk.SORT_ASCENDING:
-            sort_order = gtk.SORT_DESCENDING
-
-        else:
-            sort_order = gtk.SORT_ASCENDING
-
-        self.set_sort_order(sort_order)
-        self.set_sort_indicator(True)
-        
-        if sort_order == gtk.SORT_ASCENDING:
-            rows.sort(self._sort_ascending)
-        else:
-            rows.sort(self._sort_descending)
-
-        self.list_store.reorder([r[-1] for r in rows])
-
     def _sort_ascending(self, x, y):
         x = x[self.index]
         y = y[self.index]
@@ -713,7 +680,7 @@ class CheckColumn( gtk.TreeViewColumn ):
         y = y[self.index]
         return x - y
 
-    def _on_format(self,column, cell_renderer, tree_model, iter):
+    def _on_format(self,column, cell_renderer, tree_model, iter, format_function):
         cell_val = tree_model.get_value(iter, self.index)
         cell_renderer.set_property('inconsistent', False)
         if  cell_val == 1:        
@@ -727,9 +694,9 @@ class CheckColumn( gtk.TreeViewColumn ):
             self.extra_format_function()
     
     def _initialize_renderer( self, editable, index ):
-        self.renderer = gtk.CellRendererToggle()
+        self.renderer = Gtk.CellRendererToggle()
         self.renderer.set_property("activatable", editable)
-        col = gtk.TreeViewColumn(self.key, self.renderer, active=index)
+        col = Gtk.TreeViewColumn(self.key, self.renderer, active=index)
         self.renderer.connect("toggled", self.toggled)
 
     def toggled(self, cell, path, data=None):
@@ -743,6 +710,9 @@ class CheckColumn( gtk.TreeViewColumn ):
             dictionary = self.list_store.get_value(iter,self.dictionary_index)
             dictionary[self.key] = new_val
 
+    def set_editable(self, editable):
+        self.renderer.set_property("activatable", editable)
+
     def display_val(self, val):
         """display_val - takes a real value and returns the cooresponding
         display value
@@ -798,14 +768,14 @@ class CheckColumn( gtk.TreeViewColumn ):
             return bool(val)
 
 class DateColumn( StringColumn ):
-    """DateColumn - display data in date format. Uses a gtk.Calendar
+    """DateColumn - display data in date format. Uses a Gtk.Calendar
     to display data and support editing if enabled. Store real values as tuple.
 
     Inherits from StringColumn.
 
     """
 
-    column_type = gobject.TYPE_STRING
+    column_type = GObject.TYPE_STRING
     default_filter = grid_filter.DateFilterBox
 
     def __init__(self, key, index,dictionary_index, editable=True ):
@@ -842,30 +812,27 @@ class DateColumn( StringColumn ):
         self.renderer.set_property('editable',self._editable)
         self.renderer.connect("edited", self._cell_edited)
         
-class CellRendererDate(gtk.CellRendererText):
-
-    __gtype_name__ = 'CellRendererDate'
-
+class CellRendererDate(Gtk.CellRendererText):
     def __init__(self):
-        gtk.CellRendererText.__init__(self)
+        Gtk.CellRendererText.__init__(self)
         self.date_format = '%Y-%m-%d'
 
         self.calendar_window = None
         self.calendar = None
 
     def _create_calendar(self, treeview):
-        self.calendar_window = gtk.Dialog(parent=treeview.get_toplevel())
+        self.calendar_window = Gtk.Dialog(parent=treeview.get_toplevel())
         self.calendar_window.action_area.hide()
         self.calendar_window.set_decorated(False)
         self.calendar_window.set_property('skip-taskbar-hint', True)
 
-        self.calendar = gtk.Calendar()
-        self.calendar.display_options(gtk.CALENDAR_SHOW_DAY_NAMES | gtk.CALENDAR_SHOW_HEADING)
+        self.calendar = Gtk.Calendar()
+        self.calendar.display_options(Gtk.CalendarDisplayOptions.SHOW_DAY_NAMES | Gtk.CalendarDisplayOptions.SHOW_HEADING)
         self.calendar.connect('day-selected-double-click', self._day_selected, None)
         self.calendar.connect('key-press-event', self._day_selected)
         self.calendar.connect('focus-out-event', self._selection_cancelled)
         self.calendar_window.set_transient_for(None) # cancel the modality of dialog
-        self.calendar_window.vbox.pack_start(self.calendar)
+        self.calendar_window.vbox.pack_start(self.calendar, True, True, 0)
 
         # necessary for getting the (width, height) of calendar_window
         self.calendar.show()
@@ -900,20 +867,20 @@ class CellRendererDate(gtk.CellRendererText):
     
         response = self.calendar_window.run()
         self.calendar_window.hide()
-        if response == gtk.RESPONSE_OK:
+        if response == Gtk.ResponseType.OK:
             (year, month, day) = self.calendar.get_date()
-            date = datetime.date(year, month + 1, day).strftime(self.date_format) # gtk.Calendar's month starts from zero
+            date = datetime.date(year, month + 1, day).strftime(self.date_format) # Gtk.Calendar's month starts from zero
             self.emit('edited', path, date)
             
-        return None # don't return any editable, our gtk.Dialog did the work already
+        return None # don't return any editable, our Gtk.Dialog did the work already
 
     def _day_selected(self, calendar, event):
         # event == None for day selected via doubleclick
-        if not event or event.type == gtk.gdk.KEY_PRESS and gtk.gdk.keyval_name(event.keyval) == 'Return':
-            self.calendar_window.response(gtk.RESPONSE_OK)
+        if not event or event.type == Gdk.EventType.KEY_PRESS and Gdk.keyval_name(event.keyval) == 'Return':
+            self.calendar_window.response(Gtk.ResponseType.OK)
             return True
 
     def _selection_cancelled(self, calendar, event):
-        self.calendar_window.response(gtk.RESPONSE_CANCEL)
+        self.calendar_window.response(Gtk.ResponseType.CANCEL)
         return True
 
