@@ -18,8 +18,8 @@
 
 from testtools import TestCase
 from quickly.widgets.dictionary_grid import DictionaryGrid
-import gobject
-from quickly.widgets.grid_column import StringColumn, IntegerColumn, CurrencyColumn,CheckColumn
+from gi.repository import GObject
+from quickly.widgets.grid_column import StringColumn, IntegerColumn, CurrencyColumn,CheckColumn, DateColumn
 
 class TestDictionaryGrid(TestCase):
     """Test the CouchGrid functionality"""
@@ -42,7 +42,6 @@ class TestDictionaryGrid(TestCase):
         grid.append_row({"key1":"val11","key2":"val12"})
         self.assertEqual(len(grid.get_model()),1)
 
-
     def test_constructor_with_dicts(self):
         """test creating a grid with dictionaries in the contructor"""
         dicts = [{"key1_1": "val1_1", "key1_2": "val1_2", "key1_3": "val1_3"},
@@ -135,19 +134,33 @@ class TestDictionaryGrid(TestCase):
     def test_auto_set_col_types(self):
         """Ensure that collumn types are set properly"""
 
-        keys = ["id","price","bool?"]
-        grid = DictionaryGrid(None, keys)
-        for c in grid.get_columns():
-            col_type = c.column_type
-            key = c.key
-            if key == "id":
-                self.assertEqual(col_type,gobject.TYPE_STRING)
-            elif key == "price":
-                self.assertEqual(col_type,gobject.TYPE_STRING)
-            elif key == "bool?":
-                self.assertEqual(col_type,gobject.TYPE_INT)
-            else:
-                self.assertEqual("Extra key found",False) 
+        data = [{"id":0,"price":1.00,"bool?":True,
+                "sale price":.50, "count":50, "full count":100,
+                "date":"2010-05-05","sale date":"2010-05-06"}]
+        grid = DictionaryGrid(data)
+        c_type = type(grid.columns["id"])
+        self.assertEqual(c_type,IntegerColumn)
+
+        c_type = type(grid.columns["price"])
+        self.assertEqual(c_type,CurrencyColumn)
+
+        c_type = type(grid.columns["bool?"])
+        self.assertEqual(c_type,CheckColumn)
+
+        c_type = type(grid.columns["sale price"])
+        self.assertEqual(c_type,CurrencyColumn)
+
+        c_type = type(grid.columns["count"])
+        self.assertEqual(c_type,IntegerColumn)
+
+        c_type = type(grid.columns["full count"])
+        self.assertEqual(c_type,IntegerColumn)
+
+        c_type = type(grid.columns["date"])
+        self.assertEqual(c_type,DateColumn)
+
+        c_type = type(grid.columns["sale date"])
+        self.assertEqual(c_type,DateColumn)
 
     def test_NONE_values(self):
         keys = ["id","price","bool?","foo"]
@@ -170,13 +183,13 @@ class TestDictionaryGrid(TestCase):
             key = c.key
             col_type = c.column_type
             if key == "id":
-                self.assertEqual(col_type,gobject.TYPE_STRING)
+                self.assertEqual(col_type,GObject.TYPE_STRING)
             elif key == "price":
-                self.assertEqual(col_type,gobject.TYPE_STRING)
+                self.assertEqual(col_type,GObject.TYPE_STRING)
             elif key == "bool?":
-                self.assertEqual(col_type,gobject.TYPE_STRING)
+                self.assertEqual(col_type,GObject.TYPE_STRING)
             elif key == "foo":
-                self.assertEqual(col_type,gobject.TYPE_INT)
+                self.assertEqual(col_type,GObject.TYPE_INT)
             else:
                 self.assertEqual("Extra key Found",False) 
 
@@ -234,6 +247,16 @@ class TestDictionaryGrid(TestCase):
         self.assertTrue("key1_2" in grid.columns)
         self.assertTrue("key1_3" in grid.columns)
 
+    def test_set_editable(self):
+        keys = ["id","price","bool?"]
+        dicts = [{"price":"100.00","id":"50","bool?":"Yes"}]
+        grid = DictionaryGrid(dicts, keys)
+        grid.editable = False
+        ed1 = grid.columns["price"].get_cells()[0].get_property("editable")
+        self.assertTrue(not ed1)
+        ed2 = grid.columns["bool?"].get_cells()[0].get_property("activatable")
+        self.assertTrue(not ed2)
+
     def test_set_a_column_title(self):
         dicts = [{"key1_1": "val1_1", "key1_2": "val1_2", "key1_3": "val1_3"},
                  {"key1_1": "val2_1", "key1_2": "val2_2", "key1_3": "val2_3"},
