@@ -53,13 +53,13 @@ cam.camerbin.emit(signal_name)
 cam.pack_start(my_widget, False, False)
 
 Extending
-A WebCamBox is gtk.VBox
-A WebCamBox is a gtk.VBox that contains a gtk.DrawingArea for displaying
+A WebCamBox is Gtk.VBox
+A WebCamBox is a Gtk.VBox that contains a Gtk.DrawingArea for displaying
 webcam output, and a thin wrapper around a camerabin, which is a gstreamer
 pipleine sublcass that provides all the camera functionality.
 
 To add GUI elements simple, create them and pack them into WebCamBox, since
-it's just a gtk.VBox
+it's just a Gtk.VBox
 
 Similarly, to add to or change the web cam functionality, modify properties on
 the camerabin. You may also want to overide _on_message and/or _on_sync_message
@@ -67,18 +67,20 @@ to catch messages from the bus and add behavior.
 
 """
 
+from gi.repository import Gtk
+from gi.repository import GdkX11
+from gi.repository import GObject
+from gi.repository import Gst
+
 import sys
 import os
-import gtk
-import gst
 import datetime
-import gobject
 
 import gettext
 from gettext import gettext as _
 gettext.textdomain('quickly-widgets')
 
-class WebCamBox(gtk.VBox):
+class WebCamBox(Gtk.VBox):
     """WebCamBox - A VBox that tries to turn on and display the default webcam for the
         computer on which it is running. It is also capable of saving an image
         from the webcam to the user's Picture directory.
@@ -92,20 +94,20 @@ class WebCamBox(gtk.VBox):
         This function has no arguments
 
         """
-        gtk.VBox.__init__(self, False, 5)
-        self.video_window = gtk.DrawingArea()
+        Gtk.VBox.__init__(self, False, 5)
+        self.video_window = Gtk.DrawingArea()
         self.video_window.connect("realize",self.__on_video_window_realized)
-        self.pack_start(self.video_window, True, True)
+        self.pack_start(self.video_window, True, True, 0)
         self.video_window.show()
         self.connect("destroy", self.on_destroy)
 
-        self.camerabin = gst.element_factory_make("camerabin", "camera-source")
+        self.camerabin = Gst.ElementFactory.make("camerabin", "camera-source")
         bus = self.camerabin.get_bus()
         bus.add_signal_watch()
         bus.enable_sync_message_emission()
         bus.connect("message", self._on_message)
         bus.connect("sync-message::element", self._on_sync_message)
-        self.camerabin.set_property("image-encoder",gst.element_factory_make("pngenc", "png_encoder"))
+        #self.camerabin.set_property("image-encoder",Gst.ElementFactory.make("pngenc", "png_encoder"))
         self.filename_prefix = ""
         self.realized = False
 
@@ -122,7 +124,7 @@ class WebCamBox(gtk.VBox):
         if not self.realized:
             print _("Cannot display web cam output. Ignoring play command")
         else:
-            self.camerabin.set_state(gst.STATE_PLAYING)
+            self.camerabin.set_state(Gst.State.PLAYING)
 
     def pause(self):
         """pause - Pause the camera output. It will cause the image to
@@ -133,7 +135,7 @@ class WebCamBox(gtk.VBox):
         
         """
 
-        self.camerabin.set_state(gst.STATE_PAUSED)
+        self.camerabin.set_state(Gst.State.PAUSED)
 
     def take_picture(self):
         """take_picture - grab a frame from the web cam and save it to
@@ -155,7 +157,7 @@ class WebCamBox(gtk.VBox):
         """
 
         stamp = str(datetime.datetime.now())
-        extension = ".png"
+        extension = ".jpg"
         directory = os.environ["HOME"] + _("/Pictures/")
         self.filename = directory + self.filename_prefix + stamp + extension
         self.camerabin.set_property("filename", self.filename)
@@ -169,7 +171,7 @@ class WebCamBox(gtk.VBox):
         
         """
 
-        self.camerabin.set_state(gst.STATE_NULL)
+        self.camerabin.set_state(Gst.State.NULL)
 
     def _on_message(self, bus, message):
         """ _on_message - internal signal handler for bus messages.
@@ -183,19 +185,22 @@ class WebCamBox(gtk.VBox):
 
         """
 
+        if message is None:
+            return
+
         t = message.type
-        if t == gst.MESSAGE_ELEMENT:
+        if t == Gst.MessageType.ELEMENT:
             if message.structure.get_name() == "image-captured":
                 #work around to keep the camera working after lots
                 #of pictures are taken
-                self.camerabin.set_state(gst.STATE_NULL)
-                self.camerabin.set_state(gst.STATE_PLAYING)
+                self.camerabin.set_state(Gst.Sate.NULL)
+                self.camerabin.set_state(Gst.State.PLAYING)
 
                 self.emit("image-captured", self.filename)
 
-        if t == gst.MESSAGE_EOS:
-            self.camerabin.set_state(gst.STATE_NULL)
-        elif t == gst.MESSAGE_ERROR:
+        if t == Gst.MessageType.EOS:
+            self.camerabin.set_state(Gst.State.NULL)
+        elif t == Gst.MessageType.ERROR:
             err, debug = message.parse_error()
             print "Error: %s" % err, debug
 
@@ -217,7 +222,7 @@ class WebCamBox(gtk.VBox):
         if message_name == "prepare-xwindow-id":
             imagesink = message.src
             imagesink.set_property("force-aspect-ratio", True)
-            imagesink.set_xwindow_id(self.video_window.window.xid)
+            imagesink.set_xwindow_id(self.video_window.get_window().get_xid())
 
     def __on_video_window_realized(self, widget, data=None):
         """__on_video_window_realized - internal signal handler, used
@@ -229,16 +234,16 @@ class WebCamBox(gtk.VBox):
         self._set_video_window_id()
 
     def _set_video_window_id(self):
-        if not self.realized and self.video_window.window is not None:
-            x = self.video_window.window.xid
+        if not self.realized and self.video_window.get_window() is not None:
+            x = self.video_window.get_window().get_xid()
             self.realized = True
 
     def on_destroy(self, widget, data=None):
         #clean up the camera before exiting
-        self.camerabin.set_state(gst.STATE_NULL)
+        self.camerabin.set_state(Gst.State.NULL)
         
-    __gsignals__ = {'image-captured' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
-		(gobject.TYPE_PYOBJECT,)),
+    __gsignals__ = {'image-captured' : (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE,
+		(GObject.TYPE_PYOBJECT,)),
 		} 
 
 def __image_captured(widget, data=None):
@@ -247,20 +252,23 @@ def __image_captured(widget, data=None):
 
     """
 
-    quickly.prompts.info("WebCam Test",data)    
+    #quickly.prompts.info("WebCam Test",data) 
+    print data   
 
 if __name__ == "__main__":
     """creates a test WebCamBox"""
-    import quickly.prompts
+    #import quickly.prompts
+
+    Gst.init (sys.argv)
 
     #create and show a test window
-    win = gtk.Window(gtk.WINDOW_TOPLEVEL)
+    win = Gtk.Window()
     win.set_title("WebCam Test Window")
-    win.connect("destroy",gtk.main_quit)
+    win.connect("destroy",Gtk.main_quit)
     win.show()
 
     #create a top level container
-    vbox = gtk.VBox(False, 10)
+    vbox = Gtk.VBox(False, 10)
     vbox.show()
     win.add(vbox)
 
@@ -271,27 +279,27 @@ if __name__ == "__main__":
     mb.play()
 
     mb.connect("image-captured", __image_captured)
-    play_butt = gtk.Button("Play")
-    pause_butt = gtk.Button("Pause")
-    stop_butt = gtk.Button("Stop")
-    pic_butt = gtk.Button("Picture")
+    play_butt = Gtk.Button("Play")
+    pause_butt = Gtk.Button("Pause")
+    stop_butt = Gtk.Button("Stop")
+    pic_butt = Gtk.Button("Picture")
 
     play_butt.connect("clicked", lambda x:mb.play())
     play_butt.show()
-    mb.pack_end(play_butt, False)
+    mb.pack_end(play_butt, False, False, 0)
 
     pause_butt.connect("clicked", lambda x:mb.pause())
     pause_butt.show()
-    mb.pack_end(pause_butt, False)
+    mb.pack_end(pause_butt, False, False, 0)
 
     stop_butt.connect("clicked", lambda x:mb.stop())
     stop_butt.show()
-    mb.pack_end(stop_butt, False)
+    mb.pack_end(stop_butt, False, False, 0)
 
     pic_butt.connect("clicked", lambda x:mb.take_picture())
     pic_butt.show()
-    mb.pack_end(pic_butt, False)
+    mb.pack_end(pic_butt, False, False, 0)
 
-    gtk.main()
+    Gtk.main()
 
 
